#region File Description
//-----------------------------------------------------------------------------
// KinectHeadTrackednedModelReader.cs
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//-----------------------------------------------------------------------------
#endregion

using System.Collections.Generic;
using System.Collections.ObjectModel;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;

namespace KinectHeadTrackDataTypes
{
    /// <summary>
    /// A custom reader to read our KinectHeadTrackednedModel from an XNB.
    /// </summary>
    public class KinectHeadTrackednedModelReader : ContentTypeReader<KinectHeadTrackednedModel>
    {
        protected override KinectHeadTrackednedModel Read(ContentReader input, KinectHeadTrackednedModel existingInstance)
        {
            // read in the model parts
            List<KinectHeadTrackednedModelPart> modelParts = input.ReadObject<List<KinectHeadTrackednedModelPart>>();

            // read in the skinning data
            SkinningData skinningData = input.ReadObject<SkinningData>();

            return new KinectHeadTrackednedModel(modelParts, skinningData);
        }
    }

    /// <summary>
    /// A custom reader to read a KinectHeadTrackednedModelPart from an XNB.
    /// </summary>
    public class KinectHeadTrackednedModelPartReader : ContentTypeReader<KinectHeadTrackednedModelPart>
    {
        protected override KinectHeadTrackednedModelPart Read(ContentReader input, KinectHeadTrackednedModelPart existingInstance)
        {
            // read in all of our data
            int triangleCount = input.ReadInt32();
            CpuVertex[] cpuVertices = input.ReadObject<CpuVertex[]>();
            IndexBuffer indexBuffer = input.ReadObject<IndexBuffer>();

            // create the model part from this data
            KinectHeadTrackednedModelPart modelPart = new KinectHeadTrackednedModelPart(triangleCount, cpuVertices, indexBuffer);

            // read in the BasicEffect as a shared resource
            input.ReadSharedResource<BasicEffect>(fx => modelPart.Effect = fx);

            return modelPart;
        }
    }
}
