#region File Description
//-----------------------------------------------------------------------------
// KinectHeadTrackednedModelWriter.cs
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//-----------------------------------------------------------------------------
#endregion

using Microsoft.Xna.Framework.Content.Pipeline;
using Microsoft.Xna.Framework.Content.Pipeline.Serialization.Compiler;

namespace KinectHeadTrackPipelineExtensions
{
    /// <summary>
    /// Writes out a KinectHeadTrackednedModelContent object to an XNB file to be read in as
    /// a KinectHeadTrackednedModel.
    /// </summary>
    [ContentTypeWriter]
    class KinectHeadTrackednedModelWriter : ContentTypeWriter<KinectHeadTrackednedModelContent>
    {
        protected override void Write(ContentWriter output, KinectHeadTrackednedModelContent value)
        {
            output.WriteObject(value.ModelParts);
            output.WriteObject(value.SkinningData);
        }

        public override string GetRuntimeType(TargetPlatform targetPlatform)
        {
            return "KinectHeadTrackDataTypes.KinectHeadTrackednedModel, KinectHeadTrackDataTypes";
        }

        public override string GetRuntimeReader(TargetPlatform targetPlatform)
        {
            return "KinectHeadTrackDataTypes.KinectHeadTrackednedModelReader, KinectHeadTrackDataTypes";
        }
    }

    /// <summary>
    /// Writes out a KinectHeadTrackednedModelPartContent object to be read in as a KinectHeadTrackednedModelPart
    /// </summary>
    [ContentTypeWriter]
    class KinectHeadTrackednedModelPartWriter : ContentTypeWriter<KinectHeadTrackednedModelPartContent>
    {
        protected override void Write(ContentWriter output, KinectHeadTrackednedModelPartContent value)
        {
            output.Write(value.TriangleCount);
            output.WriteObject(value.Vertices);
            output.WriteObject(value.IndexCollection);
            output.WriteSharedResource(value.Material);
        }

        public override string GetRuntimeType(TargetPlatform targetPlatform)
        {
            return "KinectHeadTrackDataTypes.KinectHeadTrackednedModelPart, KinectHeadTrackDataTypes";
        }

        public override string GetRuntimeReader(TargetPlatform targetPlatform)
        {
            return "KinectHeadTrackDataTypes.KinectHeadTrackednedModelPartReader, KinectHeadTrackDataTypes";
        }
    }
}
